Maximum levels on log-scaled contour plots are now respected
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
When plotting contours with a log norm, passing an integer value to the ``levels``
argument to cap the maximum number of contour levels now works as intended.
